#!/bin/csh
#
#   Control script to submit multiple jobs on a cluster using
#   the Sun Grid Engine. Each job processes N particles. N is
#   specified in the 'mparameters' file as 'increment'.
#
cp mparameters mparameters_run

set start = `grep start_process mparameters_run | awk '{print $2}'`
set end   = `grep end_process mparameters_run | awk '{print $2}'`
set first = `grep first_particle mparameters_run | awk '{print $2}'`
set last  = `grep last_particle mparameters_run | awk '{print $2}'`
set data_input = `grep data_input mparameters_run | awk '{print $2}'`
set nclass = `grep nclasses mparameters_run | awk '{print $2}'`
set working_directory = `pwd`
set SCRATCH = ${working_directory}/scratch

@ n = $last - $first + 1
@ inc = $n / $nclass
@ t = $inc * $nclass
if ($t < $n) @ inc = $inc + 1
@ prev = $start - 1

set nc = 1
set firstn = $first
@ lastn = $firstn + $inc - 1
while ( $nc <= $nclass )
  cp ${data_input}_${prev}.par ${data_input}_${prev}_r${nc}.par 
  echo Submitting particles $firstn to $lastn
  qsub -pe multi 4 -l mem_free=2G -cwd -r y -V -e $SCRATCH/stderr -o $SCRATCH/stderr -N r$nc ${working_directory}/mult_reconstruct.com $firstn $lastn $prev $nc
  @ firstn = $firstn + $inc
  @ lastn = $lastn + $inc
  if ( $firstn >= $last ) set firstn = $last
  if ( $lastn >= $last ) set lastn = $last
  @ nc = $nc + 1
end

date
